use serde::{Deserialize, Serialize};
use std::collections::HashMap;

pub mod package;
pub mod fs;
pub mod bin;
pub mod build;
pub mod pkgr;

#[derive(Serialize, Deserialize)]
#[serde(default)]
pub struct Manifest<P = Option<pkgr::PKGR>> {
    pub package: package::Package,
    pub dependencies: HashMap<String, String>,
    pub fs: fs::FS,
    pub bin: Option<bin::Bin>,
    pub build: Option<build::Build>,
    pub pkgr: P
}

impl Default for Manifest {
    fn default() -> Self {
        Manifest {
            package: package::Package::default(),
            dependencies: HashMap::default(),
            fs: fs::FS::default(),
            bin: None,
            build: None,
            pkgr: None
        }
    }
}
